@@ -23,7 +23,6 @@
  * @brief  Testcase for libmicrohttpd tolerating client not closing immediately
  * @author hollosig
  */
-#define PORT	12345
 
 #include "platform.h"
 #include <stdio.h>
@@ -58,6 +57,9 @@ connection_handler (void *cls,
                     void **ptr)
 {
   static int i;
+  (void)cls;(void)url;                          /* Unused. Silent compiler warning. */
+  (void)method;(void)version;(void)upload_data; /* Unused. Silent compiler warning. */
+  (void)upload_data_size;                       /* Unused. Silent compiler warning. */
 
   if (*ptr == NULL)
     {
@@ -83,16 +85,24 @@ connection_handler (void *cls,
 static size_t
 write_data (void *ptr, size_t size, size_t nmemb, void *stream)
 {
+  (void)ptr;(void)stream;       /* Unused. Silent compiler warning. */
   return size * nmemb;
 }
 
 int
-main ()
+main (void)
 {
   struct MHD_Daemon *daemon;
+  int port;
 
-  daemon = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_DEBUG,
-                             PORT,
+  if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
+    port = 0;
+  else
+    port = 1490;
+
+
+  daemon = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
+                             port,
                              NULL,
                              NULL, connection_handler, NULL, MHD_OPTION_END);
 
@@ -101,11 +111,19 @@ main ()
       fprintf (stderr, "Daemon cannot be started!");
       exit (1);
     }
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (daemon, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        { MHD_stop_daemon (daemon); return 32; }
+      port = (int)dinfo->port;
+    }
 
   CURL *curl = curl_easy_init ();
-  //curl_easy_setopt(curl, CURLOPT_POST, 1L);
+  /* curl_easy_setopt(curl, CURLOPT_POST, 1L); */
   char url[255];
-  sprintf (url, "http://127.0.0.1:%d", PORT);
+  sprintf (url, "http://127.0.0.1:%d", port);
   curl_easy_setopt (curl, CURLOPT_URL, url);
   curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, write_data);
 
@@ -116,7 +134,7 @@ main ()
       exit (1);
     }
   /* CPU used to go crazy here */
-  sleep (1);
+  (void)sleep (1);
 
   curl_easy_cleanup (curl);
   MHD_stop_daemon (daemon);
